@@ -20,6 +20,7 @@ package com.verisign.epp.codec.launch;
 
 import java.util.ArrayList;
 import java.util.List;
+import java.util.Vector;
 
 import org.apache.log4j.Logger;
 import org.w3c.dom.Document;
@@ -29,7 +30,9 @@ import com.verisign.epp.codec.gen.EPPCodecComponent;
 import com.verisign.epp.codec.gen.EPPDecodeException;
 import com.verisign.epp.codec.gen.EPPEncodeException;
 import com.verisign.epp.codec.gen.EPPUtil;
+import com.verisign.epp.codec.signedMark.EPPEncodedSignedMark;
 import com.verisign.epp.codec.signedMark.EPPSignedMark;
+import com.verisign.epp.exception.EPPException;
 import com.verisign.epp.util.EPPCatFactory;
 import com.verisign.epp.util.EqualityUtil;
 
@@ -554,23 +557,9 @@ public class EPPLaunchCreate implements EPPCodecComponent {
 			this.type = null;
 		}
 
-		// Signed Mark (XML and Base64)
-
-		// First try Base64 encoded
+		// Signed Mark List (XML and Base64)
 		if (this.signedMarks == null) {
-			this.signedMarks = EPPUtil.decodeCompList(aElement,
-					EPPSignedMark.NS,
-					EPPSignedMark.ELM_ENCODED_SIGNED_MARK_LOCALNAME,
-					EPPSignedMark.class);
-			if (this.signedMarks != null && this.signedMarks.isEmpty()) {
-				this.signedMarks = null;
-			}
-		}
-		// Then try XML
-		if (this.signedMarks == null) {
-			this.signedMarks = EPPUtil.decodeCompList(aElement,
-					EPPSignedMark.NS, EPPSignedMark.ELM_SIGNED_MARK_LOCALNAME,
-					EPPSignedMark.class);
+			this.signedMarks = this.decodeSignedMarkList(aElement);
 			if (this.signedMarks != null && this.signedMarks.isEmpty()) {
 				this.signedMarks = null;
 			}
@@ -590,6 +579,8 @@ public class EPPLaunchCreate implements EPPCodecComponent {
 				EPPLaunchNotice.class);
 	}
 
+	
+	
 	/**
 	 * implements a deep <code>EPPLaunchCreate</code> compare.
 	 * 
@@ -654,5 +645,58 @@ public class EPPLaunchCreate implements EPPCodecComponent {
 	public String toString() {
 		return EPPUtil.toString(this);
 	}
+	
+	/**
+	 * Decodes the list of signed marks that can be either 
+	 * encoded signed marks or signed marks.  
+	 * 
+	 * @param aElement Parent element containing the list of signed marks
+	 * @return List of {@link EPPImmutableSignedMark} instances.  
+	 * @throws EPPDecodeException Error decoding the signed mark
+	 */
+	private List decodeSignedMarkList(Element aElement)
+			throws EPPDecodeException {
+		List retVal = new ArrayList();
+
+		Vector theChildren = EPPUtil.getElementsByTagNameNS(aElement,
+				EPPSignedMark.NS,
+				EPPEncodedSignedMark.ELM_ENCODED_SIGNED_MARK_LOCALNAME);
+		
+		if (theChildren.size() != 0) {
+			// For each signed mark (encoded or not)
+			for (int i = 0; i < theChildren.size(); i++) {
+				EPPSignedMark signedMark;
+				try {
+					signedMark = new EPPEncodedSignedMark();
+					signedMark.decode((Element) theChildren.elementAt(i));	
+				}
+				catch (EPPException e) {
+					throw new EPPDecodeException("Error decoding signed mark: " + e);
+				}
+				retVal.add(signedMark);
+			}
+		}
+		else {
+			theChildren = EPPUtil.getElementsByTagNameNS(aElement,
+					EPPSignedMark.NS, EPPSignedMark.ELM_SIGNED_MARK_LOCALNAME);
+		
+			// For each signed mark (encoded or not)
+			for (int i = 0; i < theChildren.size(); i++) {
+				EPPSignedMark signedMark;
+				try {
+					signedMark = new EPPSignedMark();
+					signedMark.decode((Element) theChildren.elementAt(i));
+				}
+				catch (EPPException e) {
+					throw new EPPDecodeException("Error decoding signed mark: " + e);
+				}
+				retVal.add(signedMark);
+			}
+			
+		}
+
+		return retVal;
+	}
+	
 
 }
\ No newline at end of file
