@@ -145,6 +145,19 @@ public class EPPSignedMark implements EPPCodecComponent {
 	private static XMLSignatureFactory sigFactory = XMLSignatureFactory
 			.getInstance( "DOM" );
 
+	/**
+	 * Case where constructing SMD with mark data (i.e. without signature), 
+	 * XML is not valid as per schema (Signature is required as per schema).
+	 * In this case, ignore the XML parsing exception and create a DOM object. 
+	 */
+	private static final boolean IGNORE_XML_PARSE_EXCEPTION = true;
+	
+	/**
+	 * When we construct the SMD object from EPP request, 
+	 * throw any parsing exception back to caller. 
+	 */
+	private static final boolean DO_NOT_IGNORE_XML_PARSE_EXCEPTION = false;
+	
 	/**
 	 * XML local name for the root element of the signed mark. This should be set
 	 * to <code>ELM_SIGNED_MARK_LOCALNAME</code>.
@@ -486,7 +499,7 @@ public class EPPSignedMark implements EPPCodecComponent {
 		// we do encode/docode multiple time. Also sign method sign the xml
 		// properly.
 		try {
-			this.signedMarkElement = parseAndGetDocElement( xmlBytes );
+			this.signedMarkElement = parseAndGetDocElement( xmlBytes, IGNORE_XML_PARSE_EXCEPTION );
 		}
 		catch ( EPPDecodeException e ) {
 			throw new EPPEncodeException( e );
@@ -849,6 +862,20 @@ public class EPPSignedMark implements EPPCodecComponent {
 	 */
 	private Element parseAndGetDocElement ( byte[] aSignedMarkArray )
 			throws EPPDecodeException {
+		return parseAndGetDocElement(aSignedMarkArray, DO_NOT_IGNORE_XML_PARSE_EXCEPTION);
+	}
+
+	/**
+	 * Parse the input byte array and return the DOM document element.
+	 * 
+	 * @param aSignedMarkArray
+	 *        <code>byte[]</code> to parse to create DOM element.
+	 * @return DOM element created from <code>byte[]</code>.
+	 * @throws EPPDecodeException
+	 *         thrown if any errors parsing <code>byte[]</code>.
+	 */
+	private Element parseAndGetDocElement ( byte[] aSignedMarkArray, boolean aIgnoreParsingError )
+			throws EPPDecodeException {
 		Element elm;
 		ByteArrayInputStream is = null;
 		try {
@@ -857,9 +884,9 @@ public class EPPSignedMark implements EPPCodecComponent {
 			EPPSchemaCachingParser parser = new EPPSchemaCachingParser();
 			
 			parser.setFeature(EPPSchemaCachingParser.NORMALIZE_DATA, false);
-			
-			// parser.setErrorHandler(new EPPXMLErrorHandler());
-
+			if(!aIgnoreParsingError) {
+				parser.setErrorHandler(new EPPXMLErrorHandler());
+			}
 			Document doc = parser.parse( is );
 
 			elm = doc.getDocumentElement();
