@@ -63,6 +63,17 @@ import com.verisign.epp.util.EPPCatFactory;
  * @version 1.0
  */
 public class EPPRelatedDomainExtDomainData implements EPPCodecComponent {
+	
+	/**
+	 * Constant for the delete result when the domain is deleted.
+	 */
+	public final static String DELETE_DELETED = "deleted";
+	
+	/**
+	 * 
+	 */
+	public final static String DELETE_PENDING_DELETE = "pendingDelete";
+	
 	/**
 	 * Log4j category for logging
 	 */
